@@ -3,7 +3,6 @@
 import time
 
 import adafruit_scd4x
-import board
 import busio
 from injector import singleton, inject
 
@@ -17,12 +16,14 @@ class Sensor:
     priority = 3
 
     @inject
-    def __init__(self):
-        i2c_bus = busio.I2C(board.SCL, board.SDA, frequency=100000)
+    def __init__(self, i2c_bus: busio.I2C):
         self.sensor = adafruit_scd4x.SCD4X(i2c_bus)
+        self.sensor.start_periodic_measurement()
+
+    def __del__(self):
+        self.sensor.stop_periodic_measurement()
 
     def measure(self, data_builder: DataBuilder, measurements: Measurements) -> None:
-        self.sensor.start_periodic_measurement()
 
         while True:
             if self.sensor.data_ready:
@@ -30,6 +31,4 @@ class Sensor:
                 break
             time.sleep(1)
 
-        self.sensor.stop_periodic_measurement()
-
-        data_builder.add(self.name, "CO2", "", float(CO2))
+        data_builder.add(self.name, "CO2", "ppm", float(CO2))
